Learn R Programming

adegraphics (version 1.0-9)

ADEg.Tr-class: Class "ADEg.Tr"

Description

An object of ADEg.Tr class represents triangular coordinates in 2D.

The ADEg.Tr class is a virtual class, i.e. a class which is not possible to create objects but which have heirs. This class inherits from ADEg class and has three son classes : Tr.class, Tr.label, T.match and T.traject.

Arguments

Objects from the Class

None object of this class can be instantiated.

Slots

data:

a list containing data or data's name.

  • dfxyz: the displayed values in the form of a data frame with three columns, a name or a matching call.

  • frame: a positive or null integer. It is the number of the frame containing the data (used with sys.frame(..., env = data$frame)). Only if the data are not stored (i.e. data$storeData = FALSE).

  • storeData: a logical indicating if the data should be stored in the returned object. If FALSE, only the names of the data arguments are stored.

trellis.par

a list of parameters for lattice call. It will be passed directly to par.settings arguments of the lattice function.

adeg.par

a list of graphical parameters, corresponding to the ones given by adegpar() function.

lattice.call

a list of two elements to create the trellis object:

  • graphictype: xyplot

  • arguments: its parameters to obtain the trellis object

g.args

a list containing some method parameters linked with the created object of ADEg.Tr class:

  • max3d and min3d: triangular limits

  • adjust: a logical to adjust the device with the limits

stats

a list of internal preliminary calculations

s.misc

a list of some others internal parameters:

  • adjust.update: a logical indicating if the adjust slot is updating

  • cornerp: coordinates of the triangle extremities.

  • lgrid: a list containing the three coordinates of the grid segments extremities(pts1, pts2, pts3) and the value of the division (posgrid)

Call

an object of class call

Extends

Class '>ADEg, directly.

Methods

prepare

signature(object = "ADEg.Tr"): performs the calculations before display the object (e.g. limits, grid and axis calculations)

setlatticecall

signature(object = "ADEg.Tr"): prepares the lattice.call slot

panelbase

signature(object = "ADEg.Tr"): defines the graphical background (e.g. triangle and grid)

gettrellis

signature(object = "ADEg.Tr"): converts the graphic into a trellis object of lattice class

See Also

adegpar '>Tr.class '>Tr.label '>Tr.match '>Tr.traject '>ADEg

Examples

Run this code
# NOT RUN {
showClass("ADEg.Tr")
# }

Run the code above in your browser using DataLab