Objects from the Class
C1.gauss objects can be created by calls of the form new("C1.gauss", ...). The regular usage in this package is to use the s1d.gauss function.Slots
data- a list containing data or data's name.
score: the displayed values in the form of a numeric vector, a name or a matching call.
fac: a factor for score splitting in the form of a vector, a factor, a name or a matching call.
wt: a vector of weights for score
frame: a positive or null integer. It is the number of the frame containing the data (used
with sys.frame(..., env = data$frame)). Only if the data are not stored (i.e. data$storeData = FALSE).
storeData: a logical indicating if the data should be stored in the returned object.
If FALSE, only the names of the data arguments are stored.
trellis.par- a list of parameters for
lattice call.
It will be passed directly to par.settings arguments of the lattice function. adeg.par- a list of graphical parameters, corresponding to the ones
given by
adegpar() function. lattice.call- a list to create the
trellis object. g.args- a list containing some method parameters linked with the created object of
ADEg.C1 class.
The specific slots for C1.gauss objects are:
fill: a logical to yield the gauss curves transparent.
col: a logical, a color or a colors vector to color labels, rugs, lines and polygons.
steps: a value for the number of segments used to draw Gauss curves.
stats- a list of internal preliminary calculations.
The specific slots for
C1.gauss objects are:
means: the weighted mean calculated for each fac value.
var: the weighted variance calculated for each fac value.
gausscurves: the density gauss curve calculated for each fac value.
s.misc- a list of some others internal parameters.
The specific slot for
C1.gauss objects is:
rug: an index value indicating where the rugs are drawn
Call- an object of class
call
Extends
Class ADEg.C1, directly.
Class ADEg, by class ADEg.C1, distance 2.
Class ADEgORtrellis, by class ADEg.C1, distance 3.
Class ADEgORADEgSORtrellis, by class ADEg.C1, distance 3.Methods
The methods of the father classes "ADEg.C1" and "ADEg" can be used by inheritance.
The specific methods for C1.gauss are:
- prepare
signature(object = "C1.gauss"):
calls the parent method (prepare for ADEg.C1), modifies some graphical parameters used by default and
calculates the Gauss curves according to the numeric score and the values' categories (using weighted mean and standard deviation). - panel
signature(object = "C1.gauss"):
draws Gauss curves and level names of each curve.