Learn R Programming

adegraphics (version 1.0-4)

S1.distri-class: Class S1.distri

Description

A class for the representation of a set of distributions on a numeric score.

Arguments

Objects from the Class

S1.distri objects can be created by calls of the form new("S1.distri", ...). The regular usage in this package is to use the s1d.distri function.

item

  • trellis.par
  • adeg.par
  • lattice.call
  • g.args
  • yrank: a logical to draw the distributions sorted by means ascending order.
  • stats
  • sds: the weighted variance calculated for each distribution.
  • s.misc
  • Call

code

call

itemize

  • means: the weighted mean calculated for each distribution.

Extends

Class ADEg.S1, directly. Class ADEg, by class ADEg.S1, distance 2. Class ADEgORtrellis, by class ADEg.S1, distance 3. Class ADEgORADEgSORtrellis, by class ADEg.S1, distance 3.

See Also

ADEg ADEg.S1 s1d.distri

Examples

Run this code
showClass("S1.distri")

Run the code above in your browser using DataLab