Learn R Programming

adegraphics (version 1.0-9)

addsegment: Adds segments on graphics.

Description

Adds a trellis object containing one or several segments on one or several graphical objects.

Usage

addsegment(object, x0 = NULL, y0 = NULL, x1, y1, plot = TRUE, ...)

Arguments

object

an object of class ADEg or ADEgS

x0, y0

coordinates of points FROM which to draw, passed to the panel.segments function of the lattice package. See Details.

x1, y1

coordinates of points TO which to draw, passed to the panel.segments function of the lattice package. See Details.

plot

a logical indicating if the graphics is displayed

Other arguments. Additional graphical parameters (see the plines list in adegpar and trellis.par.get). If object is an ADEgS, the argument which identify which ADEg is/are used for superposition.

Value

An object of class ADEgS.

Details

x0, y0, x1 and y1 can be vectors. A line segment is drawn, for each i, between the point (x0[i], y0[i]) and the point (x1[i], y1[i]). The coordinate vectors will be recycled to the length of the longest.

See Also

'>ADEg '>ADEgS panel.segments

Examples

Run this code
# NOT RUN {
data(deug, package = "ade4")
g11 <- s1d.density(deug$tab[, 1], plot = FALSE)
g12 <- addsegment(g11, x0 = deug$cent[1], x1 = deug$cent[1], y0 = 0, y1 = 1, 
  plines = list(col = "grey30", lwd = 3))
g13 <- addsegment(g11, 
  x0 = deug$cent + seq(0, 1, length.out = length(deug$cent)), 
  x1 = deug$cent + seq(0, 1, length.out = length(deug$cent)), 
  y0 = 0, y1 = 1, 
  plines = list(col = 1:length(deug$cent), lty = 1:length(deug$cent)))
  
# example extracted from the pedagogic file, here: http://pbil.univ-lyon1.fr/R/pdf/tdr65.pdf
data(monde84, package = "ade4")
dfX <- cbind.data.frame(lpib = log(monde84$pib), croipop = monde84$croipop)
dfY <- cbind.data.frame(lmorta = log(monde84$morta), lanal = log(monde84$anal + 1), 
  rscol = sqrt(100 - monde84$scol))
dfX0 <- ade4::scalewt(dfX)
dfY0 <- ade4::scalewt(dfY)
can1 <- cancor(dfX0, dfY0)
varcanoX <- dfX0
# }
# NOT RUN {
<!-- %*%can1$xcoef[,1] -->
# }
# NOT RUN {
varcanoY <- dfY0
# }
# NOT RUN {
<!-- %*%can1$ycoef[,1] -->
# }
# NOT RUN {
g21 <- s.label(cbind(varcanoY,varcanoX), labels = row.names(monde84), plabel.cex = 0.8, 
  plot = FALSE)
g22 <- addsegment(g21, -1.25, -1.25, 1.25, 1.25, plines.col = "purple", plines.lwd = 1.5, 
  plines.lty = 2)
# }

Run the code above in your browser using DataLab