Learn R Programming

adegraphics (version 1.0-5)

adeg.panel.hist: Panel function for adding histograms.

Description

Panel function for displaying histograms into a trellis graphic (lattice package) and level lines.

Usage

adeg.panel.hist(histValues, horizontal = TRUE, densi, drawLines, params = list(), identifier = "histogramADEg")

Arguments

histValues
an object of class histogram. See hist.
horizontal
a logical indicating if the plot is horizontal
densi
a list returns by the bkde containing the coordinates of the binned kernel density estimate of the probability density of the data
drawLines
a vector containing the level values
params
graphical parameters : plot.polygon, add.line and plot.line (lattice)
identifier
A character string that is prepended to the name of the grob that is created.

Value

Displays the histogram and level lines.

See Also

bkde and hist

Examples

Run this code
if(require(KernSmooth, quiet = TRUE) & require(lattice, quiet = TRUE)) {

  z <- round(rnorm(100, 30, 5))
  h <- hist(z, plot = FALSE)
  d <- bkde(z, kernel = "normal", gridsize = 60)
  l <- c(10, 20, 30, 40)
  xyplot(1:50 ~ 1:50, histValues = h, densi = d, drawLines = l, 
    panel = function(drawLines, histValues, densi){
      adeg.panel.hist(histValues = histValues, drawLines = drawLines, densi = densi)})
}

Run the code above in your browser using DataLab