Learn R Programming

adegraphics (version 1.0-3)

adeg.panel.nb: Panel functions for adding graphs.

Description

Panel function for representing a graph into a trellis graphic (lattice package). Two types of graph objects can be used: nb object (spdep package) or simple edges informations. Directions associated with the edges are not displayed.

Usage

adeg.panel.nb(nbobject, coords, col.edge = "black", lwd = 1, lty = 1, pch = 20, 
  cex = 1, col.node = "black", alpha = 1)

adeg.panel.edges(edges, coords, col.edge = "black", lwd = 1, lty = 1, pch = 20, cex = 1, col.node = "black", alpha = 1)

Arguments

nbobject
a object of class nb
edges
a two columns matrix, representing the edges between the nodes. For a row i, x[i, 1] and x[i, 2] are linked, x[i, 1] and x[i, 2] being vertices number.
coords
a two columns matrix containing vertices' coordinates
col.edge
edges' color(s)
lwd
line width (edges). Can be a vector
lty
line type (edges). Can be a vector
pch
vertices' representation type (symbols). Can be a vector
cex
symbols' size(s) (vertices). Can be a vector
col.node
vertices' color(s). Can be a vector
alpha
symbols' transparency

Value

  • Displays the neighboring graph.

References

Package spdep. Author: Roger Bivand

See Also

plot.nb

Examples

Run this code
if(require(maptools, quiet = TRUE) & require(lattice, quiet = TRUE) 
  & require(spdep, quiet = TRUE)) {

columbus <- readShapePoly(system.file("etc/shapes/columbus.shp", package = "spdep")[1])
coords <- coordinates(columbus)
col.gal.nb <- read.gal(system.file("etc/weights/columbus.gal", package = "spdep")[1])
nbobject <- col.gal.nb
xyplot(coords[, 2] ~ coords[, 1],
  panel = function(...){adeg.panel.nb(col.gal.nb, coords, col.edge = c("blue", "red"))})

edges <- matrix(c(1, 2, 3, 2, 4, 1, 3, 4), byrow = TRUE, ncol = 2)
coords <- matrix(c(0, 1, 1, 0, 0, -1, -1, 0), byrow = TRUE, ncol = 2)
xyplot(coords[,2] ~ coords[,1],
  panel = function(...){adeg.panel.edges(edges, coords, lty = 1:4, cex = 5)})
}

Run the code above in your browser using DataLab