Learn R Programming

adegraphics (version 1.0-3)

s1d.hist: 1-D plot of a numeric score by bars

Description

This function represents a score using a chart with rectangular bars.

Usage

s1d.hist(score, breaks = NULL, nclass = round(log2(length(score)) + 1), 
  type = c("count", "density", "percent"), right = TRUE, facets = NULL, 
  plot = TRUE, storeData = TRUE, add = FALSE, pos = -1, ...)

Arguments

score
a numeric vector (or a data frame) used to produce the plot
breaks
a vector of values to split score. If NULL, pretty(score, nclass) is used.
nclass
an integer for the number of desired intervals, ignored if breaks is not missing.
type
a value among count, density, percent to indicate the unit of the cell height.
right
a logical indicating if the histogram cells are right-closed (left open) intervals.
facets
a factor splitting score so that subsets of the data are represented on different sub-graphics
plot
a logical indicating if the graphics is displayed
storeData
a logical indicating if the data are stored in the returned object. If FALSE, only the names of the data arguments are stored
add
a logical. If TRUE, the graphic is superposed to the graphics already plotted in the current device
pos
an integer indicating the position of the environment where the data are stored, relative to the environment where the function is called. Useful only if storeData is FALSE
...
additional graphical parameters (see adegpar and trellis.par.get)

Value

  • An object of class ADEg (subclass C1.hist) or ADEgS (if add is TRUE and/or if facets or data frame for score are used). The result is displayed if plot is TRUE.

Details

Graphical parameters for polygons are available in ppolygons of adegpar. Some appropriated graphical parameters in p1d are also available.

See Also

C1.hist ADEg.C1 hist

Examples

Run this code
set.seed(40)
score1 <- rnorm(1000)
s1d.hist(score1)

Run the code above in your browser using DataLab