Learn R Programming

adegraphics (version 1.0-9)

setlimits1D: Computes limits for 1D and 2D displays.

Description

Computes limits for 1D and 2D displays adding 10% of margins around the extreme values.

Usage

setlimits1D(mini, maxi, origin, includeOr)
setlimits2D(minX, maxX, minY, maxY, origin = c(0, 0), aspect.ratio = "iso", includeOr)

Arguments

mini

the smallest value of a unidimensional dataset

maxi

the largest value of a unidimensional dataset

minX

the smallest value of the first dimension of a bidimensional dataset

maxX

the largest value of the first dimension of a bidimensional dataset

minY

the smallest value of the second dimension of a bidimensional dataset

maxY

the largest value of the second dimension of a bidimensional dataset

origin

a value (in setlimits1D) or a two-length vector (in setlimits2D) indicating origin coordinate(s)

aspect.ratio

a character string to control physical aspect ratio of the graphic. iso for isometric scales, fill for drawing as big as possible or xy for banking rule

includeOr

a boolean value indicating whether the origin is included in the graphics window

Value

setlimits1D return a two-length vector containing the limits of the graphics window on one axis sortparamADEgS return a two-length list. The first element, named xlim, is a two-length vector containing the limits of the graphics window on the first axis. The second, named ylim, is the limits on the second axis.

Examples

Run this code
# NOT RUN {
setlimits1D(mini = -2, maxi = 2, origin = 0, includeOr = TRUE)
setlimits2D(minX = -2, maxX = 2, minY = -3, maxY = 4, origin = c(0, 0), includeOr = TRUE)
# }

Run the code above in your browser using DataLab