Learn R Programming

adegraphics (version 1.0-3)

C1.curve-class: Class C1.curve

Description

A class for the creation and display of a numeric score linked by curves.

Arguments

Objects from the Class

C1.curve objects can be created by calls of the form new("C1.curve", ...). The regular usage in this package is to use the s1d.curve function.

item

  • trellis.par
  • adeg.par
  • lattice.call
  • g.args
  • stats
  • s.misc
  • Call

code

call

Extends

Class ADEg.C1, directly. Class ADEg, by class ADEg.C1, distance 2. Class ADEgORtrellis, by class ADEg.C1, distance 3. Class ADEgORADEgSORtrellis, by class ADEg.C1, distance 3.

See Also

ADEg ADEg.C1 s1d.curve

Examples

Run this code
showClass("C1.curve")

Run the code above in your browser using DataLab