Objects from the Class
C1.curve objects can be created by calls of the form new("C1.curve", ...).
The regular usage in this package is to use the s1d.curve function.item
trellis.paradeg.parlattice.callg.argsstatss.miscCall
code
callExtends
Class ADEg.C1, directly.
Class ADEg, by class ADEg.C1, distance 2.
Class ADEgORtrellis, by class ADEg.C1, distance 3.
Class ADEgORADEgSORtrellis, by class ADEg.C1, distance 3.