Learn R Programming

adegraphics (version 1.0-3)

C1.gauss-class: Class C1.gauss

Description

A class for the creation and display of a numeric score using gauss' curves.

Arguments

Objects from the Class

C1.gauss objects can be created by calls of the form new("C1.gauss", ...). The regular usage in this package is to use the s1d.gauss function.

item

  • trellis.par
  • adeg.par
  • lattice.call
  • g.args
  • col: a logical, a color or a colors vector to color labels, rugs, lines and polygons.
  • steps: a value for the number of segments used to draw Gauss curves.
  • stats
  • var: the weighted variance calculated for each fac value.
  • gausscurves: the density gauss curve calculated for each fac value.
  • s.misc
  • Call

code

call

itemize

  • rug: an index value indicating where the rugs are drawn

Extends

Class ADEg.C1, directly. Class ADEg, by class ADEg.C1, distance 2. Class ADEgORtrellis, by class ADEg.C1, distance 3. Class ADEgORADEgSORtrellis, by class ADEg.C1, distance 3.

See Also

ADEg ADEg.C1 s1d.gauss

Examples

Run this code
showClass("C1.gauss")

Run the code above in your browser using DataLab