Objects from the Class
C1.gauss objects can be created by calls of the form new("C1.gauss", ...).
The regular usage in this package is to use the s1d.gauss function.item
trellis.paradeg.parlattice.callg.argscol: a logical, a color or a colors vector to color labels, rugs, lines and polygons.steps: a value for the number of segments used to draw Gauss curves.statsvar: the weighted variance calculated for each fac value.gausscurves: the density gauss curve calculated for each fac value.s.miscCall
code
callitemize
rug: an index value indicating where the rugs are drawn
Extends
Class ADEg.C1, directly.
Class ADEg, by class ADEg.C1, distance 2.
Class ADEgORtrellis, by class ADEg.C1, distance 3.
Class ADEgORADEgSORtrellis, by class ADEg.C1, distance 3.