Objects from the Class
S1.distri objects can be created by calls of the form new("S1.distri", ...). The regular usage in this package is to use the s1d.distri function.Slots
data- a list containing data or data's name.
score: the displayed values in the form of a numeric vector, a name or a matching call.
dfdistri: the mass distribution in which each column is a class.
labels: the labels' names drawn for each distribution.
at: the index value.
frame: a positive or null integer. It is the number of the frame containing the data (used
with sys.frame(..., env = data$frame)). Only if the data are not stored (i.e. data$storeData = FALSE).
storeData: a logical indicating if the data should be stored in the returned object.
If FALSE, only the names of the data arguments are stored.
trellis.par- a list of parameters for
lattice call.
It will be passed directly to par.settings arguments of the lattice function. adeg.par- a list of graphical parameters, corresponding to the ones
given by
adegpar() function. lattice.call- a list to create the
trellis object. g.args- a list containing some method parameters linked with the created object of
ADEg.S1 class.
The specific slots for S1.distri objects are:
sdSize: the size of the standard deviation segments.
yrank: a logical to draw the distributions sorted by means ascending order.
stats- a list of internal preliminary calculations.
The specific slots for
S1.distri objects are:
means: the weighted mean calculated for each distribution.
sds: the weighted variance calculated for each distribution.
s.misc- a list of some others internal parameters
Call- an object of class
call
Extends
Class ADEg.S1, directly.
Class ADEg, by class ADEg.S1, distance 2.
Class ADEgORtrellis, by class ADEg.S1, distance 3.
Class ADEgORADEgSORtrellis, by class ADEg.S1, distance 3.Methods
The methods of the father classes "ADEg.S1" and "ADEg" can be used by inheritance.
The specific methods for S1.distri are:
- prepare
signature(object = "S1.distri"):
calls the parent method (prepare for ADEg.S1), modifies some graphical parameters used by default and calculates weighted mean and standard deviation. - panel
signature(object = "S1.distri"):
draws mean points and segments with matching labels.