Objects from the Class
S1.distri objects can be created by calls of the form new("S1.distri", ...).
The regular usage in this package is to use the s1d.distri function.item
trellis.paradeg.parlattice.callg.argsyrank: a logical to draw the distributions sorted by means ascending order.statssds: the weighted variance calculated for each distribution.s.miscCall
code
callitemize
means: the weighted mean calculated for each distribution.
Extends
Class ADEg.S1, directly.
Class ADEg, by class ADEg.S1, distance 2.
Class ADEgORtrellis, by class ADEg.S1, distance 3.
Class ADEgORADEgSORtrellis, by class ADEg.S1, distance 3.