s1d.hist(score, breaks = NULL, nclass = round(log2(length(score)) + 1),
type = c("count", "density", "percent"), right = TRUE, facets = NULL,
plot = TRUE, storeData = TRUE, add = FALSE, pos = -1, ...)score. If NULL, pretty(score, nclass) is used.breaks is not missing.count, density, percent to indicate the unit of the cell height.score so that subsets
of the data are represented on different sub-graphicsFALSE, only the names of the data
arguments are storedTRUE, the graphic is superposed to the graphics
already plotted in the current devicestoreData is
FALSEadegpar and trellis.par.get)ADEg (subclass C1.hist) or ADEgS (if add is TRUE and/or
if facets or data frame for score are used).
The result is displayed if plot is TRUE.ppolygons of adegpar.
Some appropriated graphical parameters in p1d are also available.C1.hist
ADEg.C1
histset.seed(40)
score1 <- rnorm(1000)
s1d.hist(score1)Run the code above in your browser using DataLab